---
name: Feature or Enhancement Request
about: Submit an idea. or request for a feature to be added to PySceneDetect.

---

**Description of Problem & Solution**
A clear and concise description of what the problem your feature/idea solves. Ex. PySceneDetect doesn't work well in cases X or Y but if it could detect Z [...], PySceneDetect is slow because of X but could be faster if it did Y [...], or I need PySceneDetect to do X because of some condition Y [...].

**Media Examples:**
Where possible, provide videos/images demonstrating the problem at hand or issue you would like to solve (even YouTube links are fine).

**Proposed Implementation:**
A clear and concise description of what you want to happen, how you think the feature/enhancement should be implemented. Ex. what command line options/arguments should be added to PySceneDetect, and examples of how you expect them to function.

**Alternative Solutions:**
A clear and concise list of descriptions for any alternative solutions or features you've considered.
